@@ -161,7 +161,9 @@ class Search:
         self.es.index (
             index=index,
             id=doc_id,
-            body=doc)
+            body=doc,
+            doc_type="_doc"
+        )
     
     def update_doc (self, index, doc, doc_id):
         self.es.update (
@@ -440,13 +442,13 @@ class Search:
     
     def index_variables(self, variables, index):
         for variable in variables:
-            if not self.es.exists(index,variable['element_id']):
+            if not self.es.exists(index=index,doc_id=variable['element_id']):
                 self.index_doc(
                     index=index,
                     doc=variable,
                     doc_id=variable['element_id'])
             else:
-                results = self.es.get(index, variable['element_id'])
+                results = self.es.get(index=index, doc_id=variable['element_id'])
                 identifiers = results['_source']['identifiers'] + variable['identifiers'] 
                 doc = {"doc" :{}}
                 doc['doc']['identifiers'] = identifiers
